## 港股行情

接口：hk_daily，可以通过数据工具调试和查看数据。

描述：获取港股每日增量和历史行情，每日18点左右更新当日数据

限量：单次最大提取5000行记录，可多次提取，总量不限制

积分：本接口单独开权限，具体请参阅权限说明 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| open | float | Y | 开盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| close | float | Y | 收盘价 |
| pre_close | float | Y | 昨收价 |
| change | float | Y | 涨跌额 |
| pct_chg | float | Y | 涨跌幅(%) |
| vol | float | Y | 成交量(股) |
| amount | float | Y | 成交额(元) |

接口示例

```python
pro = ts.pro_api()

#获取单一股票行情
df = pro.hk_daily(ts_code='00001.HK', start_date='20190101', end_date='20190904')

#获取某一日所有股票
df = pro.hk_daily(trade_date='20190904')
```

数据示例

```python
ts_code trade_date   open  ...  pct_chg         vol        amount
0    00001.HK   20190904  66.90  ...     3.45   8212577.0  5.619534e+08
```